summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rwxr-xr-xapp_templates/kdeapp/src/kdeapp.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/app_templates/kdeapp/src/kdeapp.py b/app_templates/kdeapp/src/kdeapp.py
index 2aa4899..64ae835 100755
--- a/app_templates/kdeapp/src/kdeapp.py
+++ b/app_templates/kdeapp/src/kdeapp.py
@@ -25,9 +25,9 @@ from kdeappview import *
description = "A KDE Application"
version = "0.1";
-class KdeApp(KMainWindow):
+class KdeApp(TDEMainWindow):
def __init__(self):
- KMainWindow.__init__(self,None,"KdeApp")
+ TDEMainWindow.__init__(self,None,"KdeApp")
self._view = KdeAppView(self)
self._printer = None
@@ -35,7 +35,7 @@ class KdeApp(KMainWindow):
# accept dnd
self.setAcceptDrops(True)
# tell the KMainWindow that this is indeed the main widget
self.setCentralWidget(self._view)
# then, setup our actions
@@ -94,7 +94,7 @@ class KdeApp(KMainWindow):
# this doesn't do anything useful. it's just here to illustrate
# how to insert a custom menu and menu item
- custom = KAction(i18n("Cus&tom Menuitem"), KShortcut(),
+ custom = TDEAction(i18n("Cus&tom Menuitem"), TDEShortcut(),
self.optionsPreferences,
self.actionCollection(), "custom_action")
self.createGUI()
@@ -258,7 +258,7 @@ def main():
# see if we are starting with session management
if kapp.isRestored():
n = 1
- while KMainWindow.canBeRestored(n):
+ while TDEMainWindow.canBeRestored(n):
KdeApp().restore(n)
n += 1
else:
@@ -35,7 +35,7 @@ class KdeApp(KMainWindow):
# accept dnd
self.setAcceptDrops(True)
- # tell the KMainWindow that this is indeed the main widget
+ # tell the TDEMainWindow that this is indeed the main widget
self.setCentralWidget(self._view)
# then, setup our actions